@@ -36,7 +36,7 @@ class BaremetalSingleTenant(baremetal_manager.BaremetalScenarioTest,
     * Delete both instances
     """
 
-    credentials = ['primary', 'alt', 'admin']
+    credentials = ['primary', 'alt', 'admin', 'system_admin']
 
     @classmethod
     def skip_checks(cls):
@@ -85,7 +85,7 @@ class BaremetalSingleTenant(baremetal_manager.BaremetalScenarioTest,
         remote.validate_authentication()
 
         cmd = 'ping %s -c4 -w4 || exit 0' % destination_ip
-        success_substring = "64 bytes from %s" % destination_ip
+        success_substring = " bytes from %s" % destination_ip
         output = remote.exec_command(cmd)
         if conn_expected:
             self.assertIn(success_substring, output)
